==> woost-0.4.1.tar.gz: woost-0.4.1/woost/extensions/sitemap/strings.py <==
#-*- coding: utf-8 -*-
"""

@author:		Martí Congost
@contact:		marti.congost@whads.com
@organization:	Whads/Accent SL
@since:			February 2010
"""
from cocktail.translations import translations

translations.define("Publishable.sitemap",
    ca = u"Refinament de l'indexat web",
    es = u"Refinamiento del indexado web",
    en = u"Web crawler hints"
)

translations.define("Publishable.sitemap_indexable",
    ca = u"Indexable",
    es = u"Indexable",
    en = u"Indexable"
)

translations.define("Publishable.sitemap_change_frequency",
    ca = u"Freqüència d'actualització",
    es = u"Frecuencia de actualización",
    en = u"Change frequency"
)

translations.define("Publishable.sitemap_priority",
    ca = u"Prioritat",
    es = u"Prioridad",
    en = u"Priority"
)

translations.define("Publishable.sitemap_priority-explanation",
    ca = u"Prioritat relativa de l'element respecte la resta de pàgines del "
         u"lloc web. S'expressa com un valor decimal entre 0 i 1.",
    es = u"Prioridad relativa del elemento respeto a la resta de páginas del "
         u"sitio web. Se expresa como un valor decimal entre 0 y 1.",
    en = u"Relative priority of the element, relative to other site content. "
         u"Expressed as a decimal number, ranging from 0 to 1."
)

translations.define("woost.extensions.sitemap.change_frequency always",
    ca = u"Sempre",
    es = u"Siempre",
    en = u"Always"
)

translations.define("woost.extensions.sitemap.change_frequency hourly",
    ca = u"Cada hora",
    es = u"Cada hora",
    en = u"Hourly"
)

translations.define("woost.extensions.sitemap.change_frequency daily",
    ca = u"Diària",
    es = u"Diaria",
    en = u"Daily"
)

translations.define("woost.extensions.sitemap.change_frequency weekly",
    ca = u"Setmanal",
    es = u"Semanal",
    en = u"Weekly"
)

translations.define("woost.extensions.sitemap.change_frequency monthly",
    ca = u"Mensual",
    es = u"Mensual",
    en = u"Monthly"
)

translations.define("woost.extensions.sitemap.change_frequency yearly",
    ca = u"Anual",
    es = u"Anual",
    en = u"Yearly"
)

translations.define("woost.extensions.sitemap.change_frequency never",
    ca = u"Mai",
    es = u"Nunca",
    en = u"Never"
)

==> woost-0.6.tar.gz: woost-0.6/woost/extensions/sitemap/strings.py <==
#-*- coding: utf-8 -*-
"""

@author:		Martí Congost
@contact:		marti.congost@whads.com
@organization:	Whads/Accent SL
@since:			February 2010
"""
from cocktail.translations import translations

translations.define("Publishable.sitemap",
    ca = u"Refinament de l'indexat web",
    es = u"Refinamiento del indexado web",
    en = u"Web crawler hints"
)

translations.define("Publishable.sitemap_indexable",
    ca = u"Indexable",
    es = u"Indexable",
    en = u"Indexable"
)

translations.define("Publishable.sitemap_change_frequency",
    ca = u"Freqüència d'actualització",
    es = u"Frecuencia de actualización",
    en = u"Change frequency"
)

translations.define("Publishable.sitemap_priority",
    ca = u"Prioritat",
    es = u"Prioridad",
    en = u"Priority"
)

translations.define("Publishable.sitemap_priority-explanation",
    ca = u"Prioritat relativa de l'element respecte la resta de pàgines del "
         u"lloc web. S'expressa com un valor decimal entre 0 i 1.",
    es = u"Prioridad relativa del elemento respecto al resto de páginas del "
         u"sitio web. Se expresa como un valor decimal entre 0 y 1.",
    en = u"Relative priority of the element, relative to other site content. "
         u"Expressed as a decimal number, ranging from 0 to 1."
)

translations.define("woost.extensions.sitemap.change_frequency always",
    ca = u"Sempre",
    es = u"Siempre",
    en = u"Always"
)

translations.define("woost.extensions.sitemap.change_frequency hourly",
    ca = u"Cada hora",
    es = u"Cada hora",
    en = u"Hourly"
)

translations.define("woost.extensions.sitemap.change_frequency daily",
    ca = u"Diària",
    es = u"Diaria",
    en = u"Daily"
)

translations.define("woost.extensions.sitemap.change_frequency weekly",
    ca = u"Setmanal",
    es = u"Semanal",
    en = u"Weekly"
)

translations.define("woost.extensions.sitemap.change_frequency monthly",
    ca = u"Mensual",
    es = u"Mensual",
    en = u"Monthly"
)

translations.define("woost.extensions.sitemap.change_frequency yearly",
    ca = u"Anual",
    es = u"Anual",
    en = u"Yearly"
)

translations.define("woost.extensions.sitemap.change_frequency never",
    ca = u"Mai",
    es = u"Nunca",
    en = u"Never"
)
